==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/MAPSCONSENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MAPSCONSENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MAPSCONSENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEAPPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEDEVICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEPRODUCT"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MAPSCONSENTID_Type", propOrder = {
    "mobileappid",
    "usercode",
    "mobiledeviceid",
    "mobileproduct"
})
public class MAPSCONSENTID_Type {

    @XmlElement(name = "MOBILEAPPID", required = true)
    protected String mobileappid;
    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "MOBILEDEVICEID", required = true)
    protected String mobiledeviceid;
    @XmlElement(name = "MOBILEPRODUCT", required = true)
    protected String mobileproduct;

    /**
     * Obtient la valeur de la propriété mobileappid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEAPPID() {
        return mobileappid;
    }

    /**
     * Définit la valeur de la propriété mobileappid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEAPPID(String value) {
        this.mobileappid = value;
    }

    /**
     * Obtient la valeur de la propriété usercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Définit la valeur de la propriété usercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Obtient la valeur de la propriété mobiledeviceid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEDEVICEID() {
        return mobiledeviceid;
    }

    /**
     * Définit la valeur de la propriété mobiledeviceid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEDEVICEID(String value) {
        this.mobiledeviceid = value;
    }

    /**
     * Obtient la valeur de la propriété mobileproduct.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEPRODUCT() {
        return mobileproduct;
    }

    /**
     * Définit la valeur de la propriété mobileproduct.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEPRODUCT(String value) {
        this.mobileproduct = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/MAPSCONSENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MAPSCONSENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MAPSCONSENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEAPPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEDEVICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEPRODUCT"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MAPSCONSENTID_Type", propOrder = {
    "mobileappid",
    "usercode",
    "mobiledeviceid",
    "mobileproduct"
})
public class MAPSCONSENTID_Type {

    @XmlElement(name = "MOBILEAPPID", required = true)
    protected String mobileappid;
    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "MOBILEDEVICEID", required = true)
    protected String mobiledeviceid;
    @XmlElement(name = "MOBILEPRODUCT", required = true)
    protected String mobileproduct;

    /**
     * Gets the value of the mobileappid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEAPPID() {
        return mobileappid;
    }

    /**
     * Sets the value of the mobileappid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEAPPID(String value) {
        this.mobileappid = value;
    }

    /**
     * Gets the value of the usercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Sets the value of the usercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Gets the value of the mobiledeviceid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEDEVICEID() {
        return mobiledeviceid;
    }

    /**
     * Sets the value of the mobiledeviceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEDEVICEID(String value) {
        this.mobiledeviceid = value;
    }

    /**
     * Gets the value of the mobileproduct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEPRODUCT() {
        return mobileproduct;
    }

    /**
     * Sets the value of the mobileproduct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEPRODUCT(String value) {
        this.mobileproduct = value;
    }

}
